@@ -16,13 +16,14 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
+
+#include <xapian.h>
+
 #include "collectionquery.h"
 #include "resultiterator_p.h"
-#include "xapian.h"
-
 
 #include <QList>
 #include <QFile>
